==> haskell-coinbase-pro-0.9.3.2-314-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-7Gasb4akvHTE78vFSkMTrF
key:                  coinbase-pro-0.9.3.2-7Gasb4akvHTE78vFSkMTrF
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  ccc81140c77525cc46fc8b56169c9867
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-7Gasb4akvHTE78vFSkMTrF
depends:
    HsOpenSSL-0.11.7.9-zHsmpwmO8aAqWon9IuYib
    aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn
    aeson-casing-0.2.0.0-AoHLGazu89yHsywg0KLicN
    async-2.2.5-D49NPDHTd69BKX3jfj3d2D base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LpBMT98fURa7l5laGpurdR exceptions-0.10.5
    http-api-data-0.5.1-8jnwYMAOuMT2sQh7hU8dcP
    http-client-0.7.18-EyzJQbPJ45W9RPu7xSmNVF
    http-client-tls-0.3.6.4-8ZVhrtbQUCNJsVgPqLCBvc
    http-streams-0.8.9.9-KNvK1A6rih2GVVmQTdr5yA
    http-types-0.12.4-9uVTqdZnsIVFg4lqnMzjN5
    io-streams-1.5.2.2-Ao4MoEJmUqdGVFQH6JES5j
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-9GVXDAVmAL58RukaX2Kymu
    servant-0.20.2-I71H44CjuKC28vh67kdJNH
    servant-client-0.20-GrcqzjUjdvB3IaSZ6QDP4j
    servant-client-core-0.20.2-LkzckSGrbpM3ONudH7W0JX
    tasty-1.4.3-AxN4ueKPnYH3P1Kge7oJuo
    tasty-hunit-0.10.1-2Sca7hQnPu9IZy640vNiXf text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-DX5d47WPsUl9FAND7kgz08
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
    uuid-1.3.16-IbAuAnYdRR9QyUPQMBTfh
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf
    websockets-0.12.7.3-6Kt6PgvqDYk3qW4eTBzKGi
    wuss-2.0.1.3-Aur6EgxeoA9IDUFvQ1b0oU

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-coinbase-pro-0.9.3.2-316-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-coinbase-pro.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 coinbase-pro
version:              0.9.3.2
visibility:           public
id:                   coinbase-pro-0.9.3.2-3YxSvHCbQ837IO2H1EOWKj
key:                  coinbase-pro-0.9.3.2-3YxSvHCbQ837IO2H1EOWKj
license:              MIT
copyright:            2022 Michael Dunn <michaelsdunn1@gmail.com>
maintainer:           Michael Dunn <michaelsdunn1@gmail.com>
author:               Michael Dunn <michaelsdunn1@gmail.com>
homepage:             https://github.com/mdunnio/coinbase-pro#readme
synopsis:             Client for Coinbase Pro
description:          Client for Coinbase Pro REST and Websocket APIs
category:             Web, Finance
abi:                  c8da105f623b28f994175df28ee4dd1e
exposed:              True
exposed-modules:
    CoinbasePro.Authenticated CoinbasePro.Authenticated.API
    CoinbasePro.Authenticated.Accounts
    CoinbasePro.Authenticated.CoinbaseAccounts
    CoinbasePro.Authenticated.Conversion
    CoinbasePro.Authenticated.Deposit CoinbasePro.Authenticated.Fills
    CoinbasePro.Authenticated.Headers CoinbasePro.Authenticated.Limits
    CoinbasePro.Authenticated.Oracle CoinbasePro.Authenticated.Orders
    CoinbasePro.Authenticated.Payment CoinbasePro.Authenticated.Profile
    CoinbasePro.Authenticated.Report CoinbasePro.Authenticated.Request
    CoinbasePro.Authenticated.Transfer
    CoinbasePro.Authenticated.Withdrawal CoinbasePro.Environment
    CoinbasePro.Headers CoinbasePro.MarketData.AggregateOrderBook
    CoinbasePro.MarketData.FullOrderBook CoinbasePro.MarketData.Types
    CoinbasePro.Request CoinbasePro.Types CoinbasePro.Unauthenticated
    CoinbasePro.Unauthenticated.API CoinbasePro.WebSocketFeed
    CoinbasePro.WebSocketFeed.Channel
    CoinbasePro.WebSocketFeed.Channel.Full.Activate
    CoinbasePro.WebSocketFeed.Channel.Full.Change
    CoinbasePro.WebSocketFeed.Channel.Full.Done
    CoinbasePro.WebSocketFeed.Channel.Full.Match
    CoinbasePro.WebSocketFeed.Channel.Full.Open
    CoinbasePro.WebSocketFeed.Channel.Full.Received
    CoinbasePro.WebSocketFeed.Channel.Heartbeat
    CoinbasePro.WebSocketFeed.Channel.Level2
    CoinbasePro.WebSocketFeed.Channel.Status
    CoinbasePro.WebSocketFeed.Channel.Ticker
    CoinbasePro.WebSocketFeed.Request
    CoinbasePro.WebSocketFeed.Response

hidden-modules:       Paths_coinbase_pro
import-dirs:          /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/coinbase-pro-0.9.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-coinbase-pro
hs-libraries:         HScoinbase-pro-0.9.3.2-3YxSvHCbQ837IO2H1EOWKj
depends:
    HsOpenSSL-0.11.7.9-zHsmpwmO8aAqWon9IuYib
    aeson-2.1.2.1-5BFfk7iI7w6HPWzhbIRzqn
    aeson-casing-0.2.0.0-AoHLGazu89yHsywg0KLicN
    async-2.2.5-D49NPDHTd69BKX3jfj3d2D base-4.17.2.1 binary-0.8.9.1
    bytestring-0.11.5.3 containers-0.6.7
    cryptonite-0.30-LpBMT98fURa7l5laGpurdR exceptions-0.10.5
    http-api-data-0.5.1-8jnwYMAOuMT2sQh7hU8dcP
    http-client-0.7.18-EyzJQbPJ45W9RPu7xSmNVF
    http-client-tls-0.3.6.4-EPZBeFlxUNP9RvBjuZP5AP
    http-streams-0.8.9.9-KNvK1A6rih2GVVmQTdr5yA
    http-types-0.12.4-9uVTqdZnsIVFg4lqnMzjN5
    io-streams-1.5.2.2-Ao4MoEJmUqdGVFQH6JES5j
    memory-0.18.0-1oHOZXUPjWrG0kImkORGvt
    network-3.1.4.0-9GVXDAVmAL58RukaX2Kymu
    servant-0.20.2-I71H44CjuKC28vh67kdJNH
    servant-client-0.20-GrcqzjUjdvB3IaSZ6QDP4j
    servant-client-core-0.20.2-LkzckSGrbpM3ONudH7W0JX
    tasty-1.4.3-AxN4ueKPnYH3P1Kge7oJuo
    tasty-hunit-0.10.1-2Sca7hQnPu9IZy640vNiXf text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unagi-streams-0.2.7-DX5d47WPsUl9FAND7kgz08
    unordered-containers-0.2.20-2eRdi4Eno3wAApPXuoC33k
    uuid-1.3.16-IbAuAnYdRR9QyUPQMBTfh
    vector-0.13.2.0-KVjnIHG2Fg91rA02TsgQOf
    websockets-0.12.7.3-6Kt6PgvqDYk3qW4eTBzKGi
    wuss-2.0.1.3-CHO3EVuHT2jsc1znxiHKb

haddock-interfaces:
    /usr/share/doc/haskell-coinbase-pro/html/coinbase-pro.haddock

haddock-html:         /usr/share/doc/haskell-coinbase-pro/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
